#define MOZ_SOURCE_STAMP 8f6abb9bb85ff3b8606f496a0406bd25e30f7b29
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-release
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-release/rev/8f6abb9bb85ff3b8606f496a0406bd25e30f7b29
